
#include <glib.h>

// Disable the 'const' function attribute of the get_type() functions.
// GCC would optimize them out because we don't use the return value.
#undef  G_GNUC_CONST
#define G_GNUC_CONST /* empty */

#include <clutter-gtkmm/wrap_init.h>
#include <glibmm/error.h>
#include <glibmm/object.h>

// #include the widget headers so that we can call the get_type() static methods:

#include "embed.h"
#include "viewport.h"

extern "C"
{

//Declarations of the *_get_type() functions:

GType gtk_clutter_embed_get_type(void);
GType gtk_clutter_viewport_get_type(void);

//Declarations of the *_error_quark() functions:

} // extern "C"


//Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:

namespace Clutter { namespace Gtk {  class Embed_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
namespace Clutter { namespace Gtk {  class Viewport_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }

namespace Clutter { namespace Gtk { 

void wrap_init()
{
  // Register Error domains:

// Map gtypes to gtkmm wrapper-creation functions:
  Glib::wrap_register(gtk_clutter_embed_get_type(), &Clutter::Gtk::Embed_Class::wrap_new);
  Glib::wrap_register(gtk_clutter_viewport_get_type(), &Clutter::Gtk::Viewport_Class::wrap_new);

  // Register the gtkmm gtypes:
  Clutter::Gtk::Embed::get_type();
  Clutter::Gtk::Viewport::get_type();

} // wrap_init()

} //Gtk
} //Clutter


